aboutsummaryrefslogtreecommitdiff
path: root/helix-term
diff options
context:
space:
mode:
Diffstat (limited to 'helix-term')
-rw-r--r--helix-term/src/commands.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/helix-term/src/commands.rs b/helix-term/src/commands.rs
index 3358f9d2..d8c56f4e 100644
--- a/helix-term/src/commands.rs
+++ b/helix-term/src/commands.rs
@@ -1189,9 +1189,9 @@ pub fn buffer_picker(cx: &mut Context) {
cx.push_layer(Box::new(picker));
}
// I inserts at the start of each line with a selection
pub fn prepend_to_line(cx: &mut Context) {
- move_line_start(cx);
+ move_first_nonwhitespace(cx);
let doc = cx.doc();
enter_insert_mode(doc);
}
@@ -1189,9 +1189,9 @@ pub fn buffer_picker(cx: &mut Context) {
cx.push_layer(Box::new(picker));
}
-// I inserts at the start of each line with a selection
+// I inserts at the first nonwhitespace character of each line with a selection
pub fn prepend_to_line(cx: &mut Context) {